
/*  -*- MaTX -*-
 *
 *  【名前】
 *      conj() - 複素共役
 *
 *  【形式】
 *      y = conj(x)
 *         (Integer|Real|Complex|Polynomial|Rational) y;
 *         (Integer|Real|Complex|Polynomial|Rational) x;
 *
 *      Y = conj(X)
 *         (Matrix|Array) Y;
 *         (Matrix|Array) X;
 *
 *  【機能説明】
 *      (整数|実数) x について，conj(x)は x 自身になる。複素数 x について，
 *      conj(x) は，x の共役複素数を求める。(多項式|有理多項式) x について，
 *      conj(x) は x の各係数を共役複素数にした値を求める。
 *
 *	    conj(X)は，(行列|配列) X の各成分に conj(X(i,j)) を作用した
 *      結果からなる(行列|配列) を求める。Y の大きさは X の大きさと
 *      同じになる。
 *
 *  【例題】
 *      >> y = conj(3.14)
 *      y = 3.14
 *      >> y = conj((3.14, 2.6))
 *      y = (3.14, -2.6)
 *      >> s = Polynomial("s");
 *      >> y = conj((1,3)*s + (2,4))
 *      y = (1,-3) s + (2,-4)
 *      >> Y = conj([(1,2), (3,4)])
 *      === [Y] : (  1,  2) ===
 *             [ (  1)-Real  (  1)-Imag ]  [ (  2)-Real  (  2)-Imag ]
 *      (  1)  1.000000E+00 -2.000000E+00  3.000000E+00 -4.000000E+00
 *
 *  【関連項目】
 *      trans(), conjtrans()
 */
