
/*  -*- MaTX -*-
 *
 *  【名前】
 *      else - 条件分岐
 *
 *  【形式】
 *      else {
 *         statements;
 *      }
 *
 *  【機能説明】
 *      else は if と対で使われ，if の条件が偽( 0 )なら else のブロック
 *      文が実行される。最も簡単な書式は
 *
 *      if (expr) {
 *          statements1;
 *      } else {
 *          statements2;
 *      }
 *
 *      である。この if-else 文では，まず expr が評価される。それが真
 *      ( 0 でない)なら statements1 が実行され，偽( 0 )なら statements2 
 *      が実行される。
 *
 *      else if は if と対で使われ，if の条件が偽( 0 )のとき，
 *      再度条件分岐を行う。if，else if，else を用いる最も簡単な書式は
 *
 *      if (expr1) {
 *          statements1;
 *      } else if (expr2) {
 *          statements2;
 *      } else {
 *          statements3;
 *      }
 *
 *      である。これは，
 *
 *      if (expr1) {
 *          statements1;
 *      } else {
 *          if (expr2) {
 *              statements2;
 *          } else {
 *              statements3;
 *          }
 *      }
 *
 *      と等価である。
 *
 *  【例題】
 *      対角成分に行番号と列番号の和，対角より上に行番号，対角より下に
 *      列番号を代入する。
 *      A = Z(4);
 *      for (i = 1; i <= Cols(A); i++) {
 *          for (j = 1; j <= Rows(A); j++) {
 *              if (i == j) {
 *                  A(i,j) = i + j;
 *              } else if (i > j) {
 *                  A(i,j) = i;
 *              } else {
 *                  A(i,j) = j;
 *              }
 *          }
 *      }
 *
 *  【関連項目】
 *      if, switch
 */
