
/*  -*- MaTX -*-
 *
 *  【名前】
 *      max_row() - 行毎の最大値
 *
 *  【形式】
 *      Y = max_row(X)     Y = max_row(X)          Y = max_row(X)
 *         Index Y;           Matrix Y;               CoMatrix Y;
 *         Index X;           (Matrix|Array) X;       (CoMatrix|CoArray) X;
 *
 *  【機能説明】
 *      X が指数のとき，max_row(X) は行毎に成分の最大値を求め，列ベクトル
 *      (指数)で返す。X が(行列|配列)のとき，max_row(X) は行毎に成分の最大
 *      値を求め，列ベクトル(行列|配列)で返す。
 *      X が複素(行列|配列)のとき，max_row(X) は行毎に絶対が最大値の成分を
 *      を求め，列ベクトル(複素行列|複素配列)で返す。
 *
 *      X が縦ベクトルまたは横ベクトルのとき，max_col(X)は，ベクトルの成分
 *      の最大値を返す。
 *
 *  【例題】
 *      >> Y = max_row([[1, -2][3, 0]])
 *      === [Y] : (  2,  1) ===
 *                 (  1)     
 *      (  1)  1.00000000E+00
 *      (  2)  3.00000000E+00
 *      >> Y = max_row([[1][3]])       
 *      === [Y] : (  1,  1) ===
 *                 (  1)     
 *      (  1)  3.00000000E+00
 *      >> Y = max_row([[(1,2), (3,4)][(5,6), (7,8)]]) 
 *      === [Y] : (  2,  1) ===
 *             [ (  1)-Real      (  1)-Imag ]
 *      (  1)  3.00000000E+00  4.00000000E+00
 *      (  2)  7.00000000E+00  8.00000000E+00
 *
 *  【関連項目】
 *      max(), max_col()
 */
