
/*  -*- MaTX -*-
 *
 *  【名前】
 *      qz() - QZ分解
 *
 *  【形式】
 *      {AA,BB,Q,Z,X,flag} = qz(A,B)
 *         CoMatrix AA;
 *         Matrix BB,Q,Z,X;
 *         Matrix A,B;
 *         int flag;
 *
 *  【機能説明】
 *      qz() は，一般化固有値の計算で使われる。正方行列 A と B に対して，
 *      {AA,BB,Q,Z,X} = qz(A,B) は，複素上三角行列 AA と 上三角行列 BB，
 *      左変換のための(直交)ユニタリ行列 Q，右変換のための直交(ユニタリ)
 *      行列 Z，一般化固有ベクトルからなる行列 X を求める。これらの行列の
 *      間には，
 *
 *      A = Q * AA * Z
 *      B = Q * BB * Z
 *      Q# * Q = I
 *      Z# * Z = I
 *
 *      A * X * diag_vec(diag_vec(BB)) = B * X * diag_vec(diag_vec(AA))
 *
 *      の関係がある。関数eig()で求まる一般化固有ベクトルは固有値の実部
 *      の降順に並べられるが，qz()で求まる一般化固有ベクトルは，並べ替え
 *      られない。
 *
 *  【アルゴリズム】
 *      Eispackの qzhes, qzit, qzval, qzvec を使用する。
 *
 *  【注意】
 *      繰り返し計算で固有値が求まらない場合は，次のメッセージが表示される。
 *
 *          Solution will not converge
 *
 *      また，flag に非零の値が返される。
 *
 *  【例題】
 *      >> A = [[1 2][6 5]];  B = [[3 4][2 1]];
 *      >> {AA, BB, Q, zz, X} = qz(A, B);
 *      >> A - Q * AA * zz#
 *      ===  ans  (   2  x   2)  CoMatrix  ===
 *             [ (  1)-Real      (  1)-Imag ]  [ (  2)-Real      (  2)-Imag ]
 *      (  1)  1.55431223E-15  0.00000000E+00  1.33226763E-15  0.00000000E+00
 *      (  2)  8.88178420E-16  0.00000000E+00  0.00000000E+00  0.00000000E+00
 *      >> B - Q * BB * zz#
 *      ===  ans  (   2  x   2)  Matrix  ===
 *                 (  1)           (  2)     
 *      (  1)  1.77635684E-15  1.33226763E-15
 *      (  2) -1.33226763E-15  3.33066907E-16
 *      >> A * X * diag_vec(diag_vec(BB)) - B * X * diag_vec(diag_vec(AA))
 *      ===  ans  (   2  x   2)  CoMatrix  ===
 *             [ (  1)-Real      (  1)-Imag ]  [ (  2)-Real      (  2)-Imag ]
 *      (  1) -2.22044605E-16  0.00000000E+00 -4.44089210E-16  0.00000000E+00
 *      (  2)  1.55431223E-15  0.00000000E+00  5.77315973E-15  0.00000000E+00
 *
 *  【関連項目】
 *      hess(), schur(), eig()
 *
 */
