
/*  -*- MaTX -*-
 *
 *  【名前】
 *      sqrt() - 平方根
 *
 *  【形式】
 *      y = sqrt(x)
 *         (Real   |Real|Complex) y;
 *         (Integer|Real|Complex) x;
 *
 *      Y = sqrt(X)
 *         Array Y;
 *         Array X;
 *
 *      Y = sqrt(X)
 *         Matrix Y;
 *         Matrix X;
 *
 *  【機能説明】
 *      sqrt(x)は，スカラ型(整数, 実数, 複素数) x の平方根を求める。
 *	    X が配列のとき，sqrt(X)は配列 X の各成分の平方根からなる配列
 *      Y を求める。Y の大きさは X の大きさと同じになる。
 *      X が行列のとき，sqrt(X)は 
 *
 *          Y*Y = X
 *
 *      を満たす X の平方根行列の 1 つを求める。
 *
 *  【アルゴリズム】
 *      平方根行列を求めるとき，Schur分解に基づく方法を利用する。
 *
 *  【例題】
 *      >> y = sqrt(2)
 *      y = 1.41421
 *      >> y = sqrt((-1,0))
 *      y = (0,1)
 *      >> y = sqrt((2,3))
 *      y = (1.67415, 0.895977)
 *      >> Y = Re(sqrt([[7 10][15 22]]))
 *      === [Y] : (  2,  2) ===
 *               (  1)           (  2)     
 *      (  1)  1.56669890E+00  1.74077656E+00
 *      (  2)  2.61116484E+00  4.17786374E+00
 *      >> Y = sqrt(Array([[7 10][15 22]]))
 *      === [Y] : (  2,  2) ===
 *                 (  1)           (  2)     
 *      (  1)  2.64575131E+00  3.16227766E+00
 *      (  2)  3.87298335E+00  4.69041576E+00
 *
 *  【関連項目】
 *      sin(), cos(), tan(), sqrt10(), exp()
 */
